Module blaxel.core.client.models.policy_spec
============================================

Classes
-------

`PolicySpec(flavors: blaxel.core.client.types.Unset | list['Flavor'] = <blaxel.core.client.types.Unset object>, locations: blaxel.core.client.types.Unset | list['PolicyLocation'] = <blaxel.core.client.types.Unset object>, max_tokens: blaxel.core.client.types.Unset | ForwardRef('PolicyMaxTokens') = <blaxel.core.client.types.Unset object>, resource_types: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, sandbox: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, type_: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Policy specification
    
    Attributes:
        flavors (Union[Unset, list['Flavor']]): Types of hardware available for deployments
        locations (Union[Unset, list['PolicyLocation']]): PolicyLocations is a local type that wraps a slice of Location
        max_tokens (Union[Unset, PolicyMaxTokens]): PolicyMaxTokens is a local type that wraps a slice of
            PolicyMaxTokens
        resource_types (Union[Unset, list[str]]): PolicyResourceTypes is a local type that wraps a slice of
            PolicyResourceType
        sandbox (Union[Unset, bool]): Sandbox mode
        type_ (Union[Unset, str]): Policy type, can be location or flavor
    
    Method generated by attrs for class PolicySpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `flavors`
    :

    `locations`
    :

    `max_tokens`
    :

    `resource_types`
    :

    `sandbox`
    :

    `type_`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :